Changes
=======
New in 0.1.8
------------
- Added more file types

New in 0.1.7
------------
- Further Python 3 support

New in 0.1.6
------------
- Preliminary support for Python 3

New in 0.1.5
------------
- Fixed compressed data bug

New in 0.1.4
------------
- Altered pyinit, PySiteApplication, PySiteConfiguration to handle apache mod_wsgi

New in 0.1.3
------------
- Altered pysite init script to copy from pysite's resource folder

New in 0.1.1
------------
- Added pysite script for site administration and testserving

New in 0.1.0
------------
- Initial distribution
